@@ -159,11 +159,6 @@ sub dir_is_dist_root ( $self, $path ) {
     return -f $path . '/share/dist.perl' ? 1 : 0;
 }
 
-# CONSTRUCTOR
-sub create ( $self, @args ) {
-    return P->class->load('Pcore::Dist::Build')->new->create(@args);
-}
-
 # BUILDERS
 sub _build_module ($self) {
     my $module_name = $self->name =~ s[-][/]smgr . '.pm';
@@ -321,27 +316,31 @@ sub version_string ($self) {
 sub _build_docker ($self) {
     if ( $self->docker_cfg && -f $self->root . 'Dockerfile' ) {
         my $docker = {
-            namespace      => $self->docker_cfg->{namespace},
-            repo_name      => lc $self->name,
-            from_repo_name => undef,
+            repo_namespace => $self->docker_cfg->{repo_namespace},
+            repo_name      => $self->docker_cfg->{repo_name},
+            repo_id        => undef,
+            from           => undef,
+            from_repo_id   => undef,
             from_tag       => undef,
         };
 
-        $docker->{id} = "$docker->{namespace}/$docker->{repo_name}";
+        return if !$docker->{repo_namespace} || !$docker->{repo_name};
+
+        $docker->{repo_id} = "$docker->{repo_namespace}/$docker->{repo_name}";
 
         my $dockerfile = P->file->read_bin( $self->root . 'Dockerfile' );
 
         if ( $dockerfile->$* =~ /^FROM\s+([^:]+):?(.*?)$/sm ) {
-            $docker->{from_repo_name} = $1;
+            $docker->{from_repo_id} = $1;
 
             $docker->{from_tag} = $2 // 'latest';
 
-            $docker->{from} = "$docker->{from_repo_name}:$docker->{from_tag}";
+            $docker->{from} = "$docker->{from_repo_id}:$docker->{from_tag}";
 
             return $docker;
         }
         else {
-            die q[Can't parse Dockerfile.];
+            die q[Error parsing "FROM" command in Dockerfile];
         }
     }
     else {
